@@ -63,8 +63,6 @@ struct _CsmConsolekitPrivate
 #endif
 };
 
-static void     csm_consolekit_class_init   (CsmConsolekitClass *klass);
-static void     csm_consolekit_init         (CsmConsolekit      *ck);
 static void     csm_consolekit_finalize     (GObject            *object);
 
 static void     csm_consolekit_free_dbus    (CsmConsolekit      *manager);
@@ -775,6 +773,12 @@ csm_consolekit_is_login_session (CsmSystem *system)
         return ret;
 }
 
+static gboolean
+csm_consolekit_can_hybrid_sleep (CsmSystem *system)
+{
+        return FALSE;
+}
+
 static gboolean
 csm_consolekit_can_suspend (CsmSystem *system)
 {
@@ -800,6 +804,11 @@ csm_consolekit_can_hibernate (CsmSystem *system)
 
 }
 
+static void
+csm_consolekit_hybrid_sleep (CsmSystem *system)
+{
+}
+
 static void
 csm_consolekit_suspend (CsmSystem *system)
 {
@@ -845,22 +854,31 @@ csm_consolekit_remove_inhibitor (CsmSystem   *system,
 {
 }
 
+static gboolean
+csm_consolekit_is_last_session_for_user (CsmSystem *system)
+{
+        return FALSE;
+}
+
 static void
 csm_consolekit_system_init (CsmSystemInterface *iface)
 {
         iface->can_switch_user = csm_consolekit_can_switch_user;
         iface->can_stop = csm_consolekit_can_stop;
         iface->can_restart = csm_consolekit_can_restart;
+        iface->can_hybrid_sleep = csm_consolekit_can_hybrid_sleep;
         iface->can_suspend = csm_consolekit_can_suspend;
         iface->can_hibernate = csm_consolekit_can_hibernate;
         iface->attempt_stop = csm_consolekit_attempt_stop;
         iface->attempt_restart = csm_consolekit_attempt_restart;
+        iface->hybrid_sleep = csm_consolekit_hybrid_sleep;
         iface->suspend = csm_consolekit_suspend;
         iface->hibernate = csm_consolekit_hibernate;
         iface->set_session_idle = csm_consolekit_set_session_idle;
         iface->is_login_session = csm_consolekit_is_login_session;
         iface->add_inhibitor = csm_consolekit_add_inhibitor;
         iface->remove_inhibitor = csm_consolekit_remove_inhibitor;
+        iface->is_last_session_for_user = csm_consolekit_is_last_session_for_user;
 }
 
 CsmConsolekit *
